[Libreoffice-commits] core.git: librelogo/source offapi/com offapi/type_reference oox/source qadevOOo/runner sw/qa sw/source vbahelper/source wizards/com writerfilter/source xmloff/source

Justin Luth justin_luth at sil.org
Wed Apr 12 15:32:17 UTC 2017


 librelogo/source/LibreLogo/LibreLogo.py                             |    8 +--
 offapi/com/sun/star/text/WrapTextMode.idl                           |    6 ++
 offapi/type_reference/offapi.idl                                    |    3 -
 oox/source/vml/vmlshape.cxx                                         |    2 
 qadevOOo/runner/util/ValueChanger.java                              |    2 
 sw/qa/extras/ooxmlexport/ooxmlexport8.cxx                           |    2 
 sw/qa/extras/ooxmlimport/ooxmlimport.cxx                            |    6 +-
 sw/qa/extras/rtfimport/rtfimport.cxx                                |    8 +--
 sw/source/core/doc/DocumentStylePoolManager.cxx                     |    2 
 sw/source/core/doc/textboxhelper.cxx                                |    4 -
 sw/source/core/draw/dcontact.cxx                                    |    4 -
 sw/source/core/edit/edfcol.cxx                                      |    2 
 sw/source/core/frmedt/fefly1.cxx                                    |    2 
 sw/source/core/frmedt/feshview.cxx                                  |    6 +-
 sw/source/core/frmedt/fews.cxx                                      |    2 
 sw/source/core/inc/sortedobjs.hxx                                   |    4 -
 sw/source/core/layout/anchoredobject.cxx                            |    2 
 sw/source/core/layout/flowfrm.cxx                                   |    2 
 sw/source/core/layout/fly.cxx                                       |    4 -
 sw/source/core/layout/flycnt.cxx                                    |    4 -
 sw/source/core/layout/frmtool.cxx                                   |    2 
 sw/source/core/layout/sortedobjs.cxx                                |    4 -
 sw/source/core/layout/tabfrm.cxx                                    |    2 
 sw/source/core/layout/trvlfrm.cxx                                   |    4 -
 sw/source/core/layout/wsfrm.cxx                                     |    4 -
 sw/source/core/objectpositioning/anchoredobjectposition.cxx         |    2 
 sw/source/core/objectpositioning/tocntntanchoredobjectposition.cxx  |    2 
 sw/source/core/objectpositioning/tolayoutanchoredobjectposition.cxx |    2 
 sw/source/core/text/itratr.cxx                                      |    2 
 sw/source/core/text/txtfly.cxx                                      |   12 ++---
 sw/source/core/unocore/unoframe.cxx                                 |    2 
 sw/source/filter/html/htmlcss1.cxx                                  |    2 
 sw/source/filter/html/htmldrawreader.cxx                            |    2 
 sw/source/filter/html/htmlform.cxx                                  |    2 
 sw/source/filter/html/htmlgrin.cxx                                  |    2 
 sw/source/filter/html/htmlplug.cxx                                  |    4 -
 sw/source/filter/html/swhtml.cxx                                    |    2 
 sw/source/filter/ww8/docxattributeoutput.cxx                        |    8 +--
 sw/source/filter/ww8/docxsdrexport.cxx                              |    2 
 sw/source/filter/ww8/rtfattributeoutput.cxx                         |    2 
 sw/source/filter/ww8/wrtw8esh.cxx                                   |    6 +-
 sw/source/filter/ww8/ww8graf.cxx                                    |    6 +-
 sw/source/filter/ww8/ww8par.cxx                                     |    2 
 sw/source/ui/frmdlg/frmpage.cxx                                     |    2 
 sw/source/ui/frmdlg/wrap.cxx                                        |    6 +-
 sw/source/ui/vba/vbawrapformat.cxx                                  |    4 -
 sw/source/uibase/shells/basesh.cxx                                  |   22 +++++-----
 sw/source/uibase/utlui/attrdesc.cxx                                 |    4 -
 sw/source/uibase/utlui/attrdesc.hrc                                 |    2 
 sw/source/uibase/utlui/attrdesc.src                                 |    2 
 vbahelper/source/vbahelper/vbashapes.cxx                            |    2 
 wizards/com/sun/star/wizards/letter/LetterDocument.py               |    4 -
 writerfilter/source/dmapper/GraphicHelpers.cxx                      |    4 -
 writerfilter/source/dmapper/GraphicImport.cxx                       |    4 -
 writerfilter/source/dmapper/OLEHandler.cxx                          |    2 
 writerfilter/source/rtftok/rtfdispatchvalue.cxx                     |    4 -
 xmloff/source/text/txtexppr.cxx                                     |    2 
 xmloff/source/text/txtprhdl.cxx                                     |    2 
 58 files changed, 113 insertions(+), 106 deletions(-)

New commits:
commit 8913353a8fd2a1d281c2d8a33ca795d97201b7bc
Author: Justin Luth <justin_luth at sil.org>
Date:   Sat Apr 1 15:31:18 2017 +0300

    enum spelling: throught -> through
    
    git grep -l  "[ _\.]THROUGHT" | xargs sed -i 's/THROUGHT/THROUGH/g'
    git grep -l -i "[ _\.]THROUGHT" | xargs sed -i 's/throught/through/g'
    
    In ENUMs: THROUGHT = THROUGH (preserved as valid alternate spelling)
    In ooxmlexport8 - unit test confirms THROUGH = THROUGHT
    
    Change-Id: Iae0fef9a8adcb96761989f38903a24ffb1b91e77
    Reviewed-on: https://gerrit.libreoffice.org/35998
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Stephan Bergmann <sbergman at redhat.com>

diff --git a/librelogo/source/LibreLogo/LibreLogo.py b/librelogo/source/LibreLogo/LibreLogo.py
index 287404d8d920..d53b5b693d3b 100644
--- a/librelogo/source/LibreLogo/LibreLogo.py
+++ b/librelogo/source/LibreLogo/LibreLogo.py
@@ -118,7 +118,7 @@ from com.sun.star.drawing import LineDash as __LineDash__
 from com.sun.star.drawing import Hatch as __Hatch__
 from com.sun.star.drawing import PolyPolygonBezierCoords as __Bezier__
 from com.sun.star.text.TextContentAnchorType import AT_PAGE as __AT_PAGE__
-from com.sun.star.text.WrapTextMode import THROUGHT as __THROUGHT__
+from com.sun.star.text.WrapTextMode import THROUGH as __THROUGH__
 from com.sun.star.drawing.LineCap import BUTT as __Cap_NONE__
 from com.sun.star.drawing.LineCap import ROUND as __Cap_ROUND__
 from com.sun.star.drawing.LineCap import SQUARE as __Cap_SQUARE__
@@ -488,7 +488,7 @@ def __initialize__():
     if not shape:
         shape = _.doc.createInstance( "com.sun.star.drawing.PolyPolygonShape" )
         shape.AnchorType = __AT_PAGE__
-        shape.TextWrap = __THROUGHT__
+        shape.TextWrap = __THROUGH__
         shape.Opaque = True
         _.drawpage.add(shape) 
         shape.PolyPolygon = __TURTLESHAPE__[0]
@@ -862,7 +862,7 @@ def __dots__(n, pos, dx, dy, r = -1, q = 0): # dots for dotted polyline or circl
 def __draw__(d, count = True):
     shape = _.doc.createInstance( "com.sun.star.drawing." + d)
     shape.AnchorType = __AT_PAGE__
-    shape.TextWrap = __THROUGHT__
+    shape.TextWrap = __THROUGH__
     __visible__(shape, False)
     while __zoom__(): # temporary fix program halt with continuous zoom
         while __zoom__():
@@ -1459,7 +1459,7 @@ def __groupend__(name = ""):
             g.setPosition(p)
         else:
             g = _.drawpage.group(__group__)
-        g.TextWrap = __THROUGHT__
+        g.TextWrap = __THROUGH__
     elif __group__.getCount() == 1:
         g = __group__.getByIndex(0)
     __grouplefthang__ = min(__groupstack__.pop(), __grouplefthang__)
diff --git a/offapi/com/sun/star/text/WrapTextMode.idl b/offapi/com/sun/star/text/WrapTextMode.idl
index a65dd8fae8e8..6344b9579044 100644
--- a/offapi/com/sun/star/text/WrapTextMode.idl
+++ b/offapi/com/sun/star/text/WrapTextMode.idl
@@ -33,7 +33,11 @@ published enum WrapTextMode
 
     /** text flow ignores the object.
      */
-    THROUGHT,
+    THROUGH,
+
+    /** text flow ignores the object: errant spelling deprecated in version 5.4
+     */
+    THROUGHT = THROUGH,
 
     /** text flows to the left and right of the object.
      */
diff --git a/offapi/type_reference/offapi.idl b/offapi/type_reference/offapi.idl
index c7268343d6f5..ebe12ed929e8 100644
--- a/offapi/type_reference/offapi.idl
+++ b/offapi/type_reference/offapi.idl
@@ -9758,7 +9758,8 @@ module com {
     };
     published enum WrapTextMode {
      NONE = 0,
-     THROUGHT = 1,
+     THROUGH = 1,
+     THROUGHT = THROUGH,  //Errant spelling deprecated in version 5.4
      PARALLEL = 2,
      DYNAMIC = 3,
      LEFT = 4,
diff --git a/oox/source/vml/vmlshape.cxx b/oox/source/vml/vmlshape.cxx
index ef9260b8d71c..badcc23f0392 100644
--- a/oox/source/vml/vmlshape.cxx
+++ b/oox/source/vml/vmlshape.cxx
@@ -539,7 +539,7 @@ void lcl_setSurround(PropertySet& rPropSet, const ShapeTypeModel& rTypeModel, co
     if (nMarginTop < -35277) // Less than 1000 points.
         aWrapType.clear();
 
-    css::text::WrapTextMode nSurround = css::text::WrapTextMode_THROUGHT;
+    css::text::WrapTextMode nSurround = css::text::WrapTextMode_THROUGH;
     if ( aWrapType == "square" || aWrapType == "tight" ||
          aWrapType == "through" )
     {
diff --git a/qadevOOo/runner/util/ValueChanger.java b/qadevOOo/runner/util/ValueChanger.java
index 3905b4485bc3..8a6c51936863 100644
--- a/qadevOOo/runner/util/ValueChanger.java
+++ b/qadevOOo/runner/util/ValueChanger.java
@@ -191,7 +191,7 @@ public class ValueChanger {
             com.sun.star.text.WrapTextMode WTM3 = com.sun.star.text.WrapTextMode.NONE;
             com.sun.star.text.WrapTextMode WTM4 = com.sun.star.text.WrapTextMode.PARALLEL;
             com.sun.star.text.WrapTextMode WTM5 = com.sun.star.text.WrapTextMode.RIGHT;
-            com.sun.star.text.WrapTextMode WTM6 = com.sun.star.text.WrapTextMode.THROUGHT;
+            com.sun.star.text.WrapTextMode WTM6 = com.sun.star.text.WrapTextMode.THROUGH;
             if (oldValue.equals(WTM1))
                 newValue = WTM2;
             if (oldValue.equals(WTM2))
diff --git a/sw/qa/extras/ooxmlexport/ooxmlexport8.cxx b/sw/qa/extras/ooxmlexport/ooxmlexport8.cxx
index b954283754a9..a84c8256267d 100644
--- a/sw/qa/extras/ooxmlexport/ooxmlexport8.cxx
+++ b/sw/qa/extras/ooxmlexport/ooxmlexport8.cxx
@@ -1297,6 +1297,8 @@ DECLARE_OOXMLEXPORT_TEST(testWpsOnly, "wps-only.docx")
     // Left margin was 0, instead of 114300 EMU's.
     CPPUNIT_ASSERT_EQUAL(sal_Int32(318), getProperty<sal_Int32>(xShape, "LeftMargin"));
     // Wrap type was PARALLEL.
+    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGH, getProperty<text::WrapTextMode>(xShape, "Surround"));
+    // Confirm that the deprecated (incorrectly spelled) _THROUGHT also matches
     CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGHT, getProperty<text::WrapTextMode>(xShape, "Surround"));
 
     // This should be in front of text.
diff --git a/sw/qa/extras/rtfimport/rtfimport.cxx b/sw/qa/extras/rtfimport/rtfimport.cxx
index f8529679c4a0..d0d12b168de2 100644
--- a/sw/qa/extras/rtfimport/rtfimport.cxx
+++ b/sw/qa/extras/rtfimport/rtfimport.cxx
@@ -912,7 +912,7 @@ DECLARE_RTFIMPORT_TEST(testInk, "ink.rtf")
             rProp.Value >>= aSegments;
     }
     CPPUNIT_ASSERT_EQUAL(sal_Int16(10), aSegments[1].Count);
-    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGHT, getProperty<text::WrapTextMode>(getShape(1), "Surround"));
+    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGH, getProperty<text::WrapTextMode>(getShape(1), "Surround"));
 }
 
 DECLARE_RTFIMPORT_TEST(testFdo52389, "fdo52389.rtf")
@@ -1137,7 +1137,7 @@ DECLARE_RTFIMPORT_TEST(testFdo57678, "fdo57678.rtf")
 DECLARE_RTFIMPORT_TEST(testFdo45183, "fdo45183.rtf")
 {
     // Was text::WrapTextMode_PARALLEL, i.e. shpfblwtxt didn't send the shape below text.
-    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGHT, getProperty<text::WrapTextMode>(getShape(1), "Surround"));
+    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGH, getProperty<text::WrapTextMode>(getShape(1), "Surround"));
 
     uno::Reference<text::XTextTablesSupplier> xTextTablesSupplier(mxComponent, uno::UNO_QUERY);
     uno::Reference<container::XIndexAccess> xTables(xTextTablesSupplier->getTextTables(), uno::UNO_QUERY);
@@ -2103,7 +2103,7 @@ DECLARE_RTFIMPORT_TEST(testBehindDoc, "behind-doc.rtf")
 {
     // The problem was that "behind doc" didn't result in the shape being in the background, only in being wrapped as "through".
     uno::Reference<drawing::XShape> xShape = getShape(1);
-    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGHT, getProperty<text::WrapTextMode>(xShape, "Surround"));
+    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGH, getProperty<text::WrapTextMode>(xShape, "Surround"));
     // This was true.
     CPPUNIT_ASSERT_EQUAL(false, getProperty<bool>(xShape, "Opaque"));
 }
@@ -2438,7 +2438,7 @@ DECLARE_RTFIMPORT_TEST(testFdo49893_3, "fdo49893-3.rtf")
     }
 
     // Correct wrapping for shape
-    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGHT, getProperty<text::WrapTextMode>(getShape(2), "Surround"));
+    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGH, getProperty<text::WrapTextMode>(getShape(2), "Surround"));
 }
 
 DECLARE_RTFIMPORT_TEST(testFdo89496, "fdo89496.rtf")
diff --git a/sw/source/core/doc/DocumentStylePoolManager.cxx b/sw/source/core/doc/DocumentStylePoolManager.cxx
index c911c72b09b4..5dab3be1472d 100644
--- a/sw/source/core/doc/DocumentStylePoolManager.cxx
+++ b/sw/source/core/doc/DocumentStylePoolManager.cxx
@@ -1332,7 +1332,7 @@ SwFormat* DocumentStylePoolManager::GetFormatFromPool( sal_uInt16 nId )
             aSet.Put( SwFormatHoriOrient( 0, text::HoriOrientation::CENTER, text::RelOrientation::FRAME ));
             aSet.Put( SwFormatVertOrient( 0, text::VertOrientation::CENTER, text::RelOrientation::FRAME ));
             aSet.Put( SvxOpaqueItem( RES_OPAQUE, false ));
-            aSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGHT ));
+            aSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGH ));
         }
         break;
     case RES_POOLFRM_LABEL:
diff --git a/sw/source/core/doc/textboxhelper.cxx b/sw/source/core/doc/textboxhelper.cxx
index 718b5fe5f227..2eb223dc66a1 100644
--- a/sw/source/core/doc/textboxhelper.cxx
+++ b/sw/source/core/doc/textboxhelper.cxx
@@ -229,7 +229,7 @@ void SwTextBoxHelper::getShapeWrapThrough(const SwFrameFormat* pTextBox, bool& r
 {
     SwFrameFormat* pShape = SwTextBoxHelper::getOtherTextBoxFormat(pTextBox, RES_FLYFRMFMT);
     if (pShape)
-        rWrapThrough = pShape->GetSurround().GetSurround() == css::text::WrapTextMode_THROUGHT;
+        rWrapThrough = pShape->GetSurround().GetSurround() == css::text::WrapTextMode_THROUGH;
 }
 
 SwFrameFormat* SwTextBoxHelper::getOtherTextBoxFormat(const SwFrameFormat* pFormat, sal_uInt16 nType)
@@ -467,7 +467,7 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_u
                     uno::Reference<beans::XPropertySet> const xPropertySet(
                         SwXTextFrame::CreateXTextFrame(*pFormat->GetDoc(), pFormat),
                         uno::UNO_QUERY);
-                    xPropertySet->setPropertyValue(UNO_NAME_SURROUND, uno::makeAny(text::WrapTextMode_THROUGHT));
+                    xPropertySet->setPropertyValue(UNO_NAME_SURROUND, uno::makeAny(text::WrapTextMode_THROUGH));
                     return;
                 }
                 break;
diff --git a/sw/source/core/draw/dcontact.cxx b/sw/source/core/draw/dcontact.cxx
index 883cc616db64..4854824d7300 100644
--- a/sw/source/core/draw/dcontact.cxx
+++ b/sw/source/core/draw/dcontact.cxx
@@ -139,7 +139,7 @@ bool HasWrap( const SdrObject* pObj )
         const SwFrameFormat* pFormat = ::FindFrameFormat( pObj );
         if ( pFormat )
         {
-            return css::text::WrapTextMode_THROUGHT != pFormat->GetSurround().GetSurround();
+            return css::text::WrapTextMode_THROUGH != pFormat->GetSurround().GetSurround();
         }
     }
 
@@ -1101,7 +1101,7 @@ void SwDrawContact::Changed_( const SdrObject& rObj,
     // improvement: determine as-character anchored object flag only once.
     const bool bAnchoredAsChar = ObjAnchoredAsChar();
     const bool bNotify = !(GetFormat()->GetDoc()->IsInDtor()) &&
-                         ( css::text::WrapTextMode_THROUGHT != GetFormat()->GetSurround().GetSurround() ) &&
+                         ( css::text::WrapTextMode_THROUGH != GetFormat()->GetSurround().GetSurround() ) &&
                          !bAnchoredAsChar;
     switch( eType )
     {
diff --git a/sw/source/core/edit/edfcol.cxx b/sw/source/core/edit/edfcol.cxx
index cac8d8c11e32..7de9077240fb 100644
--- a/sw/source/core/edit/edfcol.cxx
+++ b/sw/source/core/edit/edfcol.cxx
@@ -315,7 +315,7 @@ void SwEditShell::SetClassification(const OUString& rName, SfxClassificationPoli
                     xPropertySet->setPropertyValue(UNO_NAME_TEXT_AUTOGROWWIDTH, uno::makeAny(false));
                     xPropertySet->setPropertyValue(UNO_NAME_TEXT_MINFRAMEHEIGHT, uno::makeAny(nHeight));
                     xPropertySet->setPropertyValue(UNO_NAME_TEXT_MINFRAMEWIDTH, uno::makeAny(nWidth));
-                    xPropertySet->setPropertyValue(UNO_NAME_TEXT_WRAP, uno::makeAny(text::WrapTextMode_THROUGHT));
+                    xPropertySet->setPropertyValue(UNO_NAME_TEXT_WRAP, uno::makeAny(text::WrapTextMode_THROUGH));
                     xPropertySet->setPropertyValue(UNO_NAME_VERT_ORIENT_RELATION, uno::makeAny(static_cast<sal_Int16>(text::RelOrientation::PAGE_PRINT_AREA)));
                     xPropertySet->setPropertyValue(UNO_NAME_CHAR_FONT_NAME, uno::makeAny(OUString("Liberation Sans")));
                     xPropertySet->setPropertyValue("Transformation", uno::makeAny(aMatrix));
diff --git a/sw/source/core/frmedt/fefly1.cxx b/sw/source/core/frmedt/fefly1.cxx
index a3f167e1b15d..0ae32beb8608 100644
--- a/sw/source/core/frmedt/fefly1.cxx
+++ b/sw/source/core/frmedt/fefly1.cxx
@@ -884,7 +884,7 @@ void SwFEShell::InsertDrawObj( SdrObject& rDrawObj,
     SfxItemSet rFlyAttrSet( GetDoc()->GetAttrPool(), aFrameFormatSetRange );
     rFlyAttrSet.Put( SwFormatAnchor( RndStdIds::FLY_AT_PARA ));
     // #i89920#
-    rFlyAttrSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGHT ) );
+    rFlyAttrSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGH ) );
     rDrawObj.SetLayer( getIDocumentDrawModelAccess().GetHeavenId() );
 
     // find anchor position
diff --git a/sw/source/core/frmedt/feshview.cxx b/sw/source/core/frmedt/feshview.cxx
index 62de57d3ad79..05218530c5fd 100644
--- a/sw/source/core/frmedt/feshview.cxx
+++ b/sw/source/core/frmedt/feshview.cxx
@@ -1314,7 +1314,7 @@ bool SwFEShell::ShouldObjectBeSelected(const Point& rPt)
                     const SwAnchoredObject* pAnchoredObj = ::GetUserCall( pObj )->GetAnchoredObj( pObj );
                     const SwFrameFormat& rFormat = pAnchoredObj->GetFrameFormat();
                     const SwFormatSurround& rSurround = rFormat.GetSurround();
-                    if ( rSurround.GetSurround() == css::text::WrapTextMode_THROUGHT )
+                    if ( rSurround.GetSurround() == css::text::WrapTextMode_THROUGH )
                     {
                         bObjInBackground = true;
                     }
@@ -1991,7 +1991,7 @@ bool SwFEShell::ImpEndCreate()
             aRelNullPt = rBound.TopLeft();
 
         aSet.Put( aAnch );
-        aSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGHT ) );
+        aSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGH ) );
         // OD 2004-03-30 #i26791# - set horizontal position
         SwFormatHoriOrient aHori( nXOffset, text::HoriOrientation::NONE, text::RelOrientation::FRAME );
         aSet.Put( aHori );
@@ -2719,7 +2719,7 @@ void SwFEShell::CheckUnboundObjects()
                 aRelNullPt = rBound.TopLeft();
 
             aSet.Put( aAnch );
-            aSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGHT ) );
+            aSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGH ) );
             SwFrameFormat* pFormat = getIDocumentLayoutAccess().MakeLayoutFormat( RndStdIds::DRAW_OBJECT, &aSet );
 
             SwDrawContact *pContact = new SwDrawContact(
diff --git a/sw/source/core/frmedt/fews.cxx b/sw/source/core/frmedt/fews.cxx
index 44384a5a9ec2..d1b2a0906454 100644
--- a/sw/source/core/frmedt/fews.cxx
+++ b/sw/source/core/frmedt/fews.cxx
@@ -731,7 +731,7 @@ void SwFEShell::CalcBoundRect( SwRect& _orRect,
     {
         SwFlyFrameFormat* pFormat = const_cast<SwFlyFrameFormat*>(pFly->GetFormat());
         const SwFormatSurround& rSurround = pFormat->GetSurround();
-        bWrapThrough = rSurround.GetSurround() == css::text::WrapTextMode_THROUGHT;
+        bWrapThrough = rSurround.GetSurround() == css::text::WrapTextMode_THROUGH;
     }
 
     const SwPageFrame* pPage = pFrame->FindPageFrame();
diff --git a/sw/source/core/inc/sortedobjs.hxx b/sw/source/core/inc/sortedobjs.hxx
index ba3c34408ef4..0e9075917e52 100644
--- a/sw/source/core/inc/sortedobjs.hxx
+++ b/sw/source/core/inc/sortedobjs.hxx
@@ -34,8 +34,8 @@ class SwAnchoredObject;
       - order 1: to-page, 2: to-fly, 3: to-paragraph|to-character|as-character
     - anchor node
     - wrapping style (inclusive layer)
-      - order 1: wrapping style != css::text::WrapTextMode_THROUGHT and not in hell layer,
-        2: wrapping style = css::text::WrapTextMode_THROUGHT or in hell layer
+      - order 1: wrapping style != css::text::WrapTextMode_THROUGH and not in hell layer,
+        2: wrapping style = css::text::WrapTextMode_THROUGH or in hell layer
     - wrapping style influence
       - order 1: NONE_SUCCESSIVE_POSITIONED, 2: NONE_CONCURRENT_POSITIONED
     - again anchor type
diff --git a/sw/source/core/layout/anchoredobject.cxx b/sw/source/core/layout/anchoredobject.cxx
index a1d2080d7856..4b79a357771f 100644
--- a/sw/source/core/layout/anchoredobject.cxx
+++ b/sw/source/core/layout/anchoredobject.cxx
@@ -427,7 +427,7 @@ bool SwAnchoredObject::ConsiderObjWrapInfluenceOnObjPos() const
         const SwFormatAnchor& rAnchor = rObjFormat.GetAnchor();
         if ( ((rAnchor.GetAnchorId() == RndStdIds::FLY_AT_CHAR) ||
               (rAnchor.GetAnchorId() == RndStdIds::FLY_AT_PARA)) &&
-             rObjFormat.GetSurround().GetSurround() != css::text::WrapTextMode_THROUGHT )
+             rObjFormat.GetSurround().GetSurround() != css::text::WrapTextMode_THROUGH )
         {
             // --> #i34520# - text also wraps around anchored
             // objects in the layer Hell - see the text formatting.
diff --git a/sw/source/core/layout/flowfrm.cxx b/sw/source/core/layout/flowfrm.cxx
index e2162e1bb51c..3c6198e15b24 100644
--- a/sw/source/core/layout/flowfrm.cxx
+++ b/sw/source/core/layout/flowfrm.cxx
@@ -303,7 +303,7 @@ sal_uInt8 SwFlowFrame::BwdMoveNecessary( const SwPageFrame *pPage, const SwRect
             const SwFrameFormat& rFormat = pObj->GetFrameFormat();
             const SwRect aRect( pObj->GetObjRect() );
             if ( aRect.IsOver( rRect ) &&
-                 rFormat.GetSurround().GetSurround() != css::text::WrapTextMode_THROUGHT )
+                 rFormat.GetSurround().GetSurround() != css::text::WrapTextMode_THROUGH )
             {
                 if( m_rThis.IsLayoutFrame() && //Fly Lower of This?
                     Is_Lower_Of( &m_rThis, pObj->GetDrawObj() ) )
diff --git a/sw/source/core/layout/fly.cxx b/sw/source/core/layout/fly.cxx
index 704f28542f7f..13fe44ad08dc 100644
--- a/sw/source/core/layout/fly.cxx
+++ b/sw/source/core/layout/fly.cxx
@@ -1464,7 +1464,7 @@ void CalcContent( SwLayoutFrame *pLay, bool bNoColl )
                                 // Prevent oscillation
                                 SwFrameFormat& rFormat = pAnchoredObj->GetFrameFormat();
                                 SwFormatSurround aAttr( rFormat.GetSurround() );
-                                if( css::text::WrapTextMode_THROUGHT != aAttr.GetSurround() )
+                                if( css::text::WrapTextMode_THROUGH != aAttr.GetSurround() )
                                 {
                                     // When on auto position, we can only set it to
                                     // flow through
@@ -1473,7 +1473,7 @@ void CalcContent( SwLayoutFrame *pLay, bool bNoColl )
                                         (css::text::WrapTextMode_PARALLEL ==
                                             aAttr.GetSurround()))
                                     {
-                                        aAttr.SetSurround( css::text::WrapTextMode_THROUGHT );
+                                        aAttr.SetSurround( css::text::WrapTextMode_THROUGH );
                                     }
                                     else
                                     {
diff --git a/sw/source/core/layout/flycnt.cxx b/sw/source/core/layout/flycnt.cxx
index 6cdf0a9500d0..23500f5e8107 100644
--- a/sw/source/core/layout/flycnt.cxx
+++ b/sw/source/core/layout/flycnt.cxx
@@ -347,7 +347,7 @@ void SwFlyAtContentFrame::MakeAll(vcl::RenderContext* pRenderContext)
                     SwFormatSurround aMain( pFormat->GetSurround() );
                     if ( aMain.GetSurround() == css::text::WrapTextMode_NONE )
                     {
-                        aMain.SetSurround( css::text::WrapTextMode_THROUGHT );
+                        aMain.SetSurround( css::text::WrapTextMode_THROUGH );
                         pFormat->SetFormatAttr( aMain );
                     }
                     pFormat->UnlockModify();
@@ -466,7 +466,7 @@ void SwFlyAtContentFrame::MakeAll(vcl::RenderContext* pRenderContext)
                             if ( aSurround.GetSurround() == css::text::WrapTextMode_NONE )
                             {
                                 pFormat->LockModify();
-                                aSurround.SetSurround( css::text::WrapTextMode_THROUGHT );
+                                aSurround.SetSurround( css::text::WrapTextMode_THROUGH );
                                 pFormat->SetFormatAttr( aSurround );
                                 pFormat->UnlockModify();
                                 bOsz = false;
diff --git a/sw/source/core/layout/frmtool.cxx b/sw/source/core/layout/frmtool.cxx
index b81dca783f0c..833357dae20b 100644
--- a/sw/source/core/layout/frmtool.cxx
+++ b/sw/source/core/layout/frmtool.cxx
@@ -2883,7 +2883,7 @@ void Notify_Background( const SdrObject* pObj,
                     && pFlyFrame // TODO: do it for draw objects too?
                     && pTab->IsFollow() // table starts on previous page?
                     // "through" means they will actually overlap anyway
-                    && css::text::WrapTextMode_THROUGHT != pFlyFrame->GetFormat()->GetSurround().GetSurround()
+                    && css::text::WrapTextMode_THROUGH != pFlyFrame->GetFormat()->GetSurround().GetSurround()
                     // if it's anchored in footer it can't move to other page
                     && !pAnchor->FindFooterOrHeader())
                 {
diff --git a/sw/source/core/layout/sortedobjs.cxx b/sw/source/core/layout/sortedobjs.cxx
index da019d065046..a3e2a9fad81f 100644
--- a/sw/source/core/layout/sortedobjs.cxx
+++ b/sw/source/core/layout/sortedobjs.cxx
@@ -160,11 +160,11 @@ struct ObjAnchorOrder
         const SdrLayerID nHellId = rIDDMA.GetHellId();
         const SdrLayerID nInvisibleHellId = rIDDMA.GetInvisibleHellId();
         const bool bWrapThroughOrHellListed =
-                    rFormatListed.GetSurround().GetSurround() == css::text::WrapTextMode_THROUGHT ||
+                    rFormatListed.GetSurround().GetSurround() == css::text::WrapTextMode_THROUGH ||
                     _pListedAnchoredObj->GetDrawObj()->GetLayer() == nHellId ||
                     _pListedAnchoredObj->GetDrawObj()->GetLayer() == nInvisibleHellId;
         const bool bWrapThroughOrHellNew =
-                    rFormatNew.GetSurround().GetSurround() == css::text::WrapTextMode_THROUGHT ||
+                    rFormatNew.GetSurround().GetSurround() == css::text::WrapTextMode_THROUGH ||
                     _pNewAnchoredObj->GetDrawObj()->GetLayer() == nHellId ||
                     _pNewAnchoredObj->GetDrawObj()->GetLayer() == nInvisibleHellId;
         if ( bWrapThroughOrHellListed != bWrapThroughOrHellNew )
diff --git a/sw/source/core/layout/tabfrm.cxx b/sw/source/core/layout/tabfrm.cxx
index 8246b5123efc..4d62e42840c2 100644
--- a/sw/source/core/layout/tabfrm.cxx
+++ b/sw/source/core/layout/tabfrm.cxx
@@ -4935,7 +4935,7 @@ void SwCellFrame::Format( vcl::RenderContext* /*pRenderContext*/, const SwBorder
                     const SwFrameFormat& rAnchoredObjFrameFormat = pAnchoredObj->GetFrameFormat();
                     const SwFormatSurround &rSur = rAnchoredObjFrameFormat.GetSurround();
 
-                    if ( css::text::WrapTextMode_THROUGHT != rSur.GetSurround() )
+                    if ( css::text::WrapTextMode_THROUGH != rSur.GetSurround() )
                     {
                         // frames, which the cell is a lower of, aren't relevant
                         if ( dynamic_cast< const SwFlyFrame *>( pAnchoredObj ) !=  nullptr )
diff --git a/sw/source/core/layout/trvlfrm.cxx b/sw/source/core/layout/trvlfrm.cxx
index f4cc42c090af..60e1ed637138 100644
--- a/sw/source/core/layout/trvlfrm.cxx
+++ b/sw/source/core/layout/trvlfrm.cxx
@@ -64,7 +64,7 @@ namespace {
             const SwAnchoredObject* pAnchoredObj = GetUserCall( aIter() )->GetAnchoredObj( aIter() );
             const SwFormatSurround& rSurround = pAnchoredObj->GetFrameFormat().GetSurround();
             const SvxOpaqueItem& rOpaque = pAnchoredObj->GetFrameFormat().GetOpaque();
-            bool bInBackground = ( rSurround.GetSurround() == css::text::WrapTextMode_THROUGHT ) && !rOpaque.GetValue();
+            bool bInBackground = ( rSurround.GetSurround() == css::text::WrapTextMode_THROUGH ) && !rOpaque.GetValue();
 
             bool bBackgroundMatches = ( bInBackground && bSearchBackground ) ||
                                       ( !bInBackground && !bSearchBackground );
@@ -2570,7 +2570,7 @@ void SwRootFrame::CalcFrameRects(SwShellCursor &rCursor)
                 if( inSelection )
                         Add( aRegion, pFly->Frame() );
                 else if ( !pFly->IsAnLower( pStartFrame ) &&
-                    (rSur.GetSurround() != css::text::WrapTextMode_THROUGHT &&
+                    (rSur.GetSurround() != css::text::WrapTextMode_THROUGH &&
                     !rSur.IsContour()) )
                 {
                     if ( aSortObjs.Contains( *pAnchoredObj ) )
diff --git a/sw/source/core/layout/wsfrm.cxx b/sw/source/core/layout/wsfrm.cxx
index 12ebf555d498..6cf82e5fa852 100644
--- a/sw/source/core/layout/wsfrm.cxx
+++ b/sw/source/core/layout/wsfrm.cxx
@@ -1900,7 +1900,7 @@ SwTwips SwContentFrame::ShrinkFrame( SwTwips nDist, bool bTst, bool bInfo )
                     if( aBound.IsOver( aRect ) )
                     {
                         const SwFrameFormat& rFormat = pAnchoredObj->GetFrameFormat();
-                        if( css::text::WrapTextMode_THROUGHT != rFormat.GetSurround().GetSurround() )
+                        if( css::text::WrapTextMode_THROUGH != rFormat.GetSurround().GetSurround() )
                         {
                             const SwFrame* pAnchor = pAnchoredObj->GetAnchorFrame();
                             if ( pAnchor && pAnchor->FindFooterOrHeader() == GetUpper() )
@@ -3087,7 +3087,7 @@ static void InvaPercentFlys( SwFrame *pFrame, SwTwips nDiff )
                     if( pFly->Frame().Height()*10 >
                         ( nDiff + pRel->Prt().Height() )*9 &&
                         pFly->GetFormat()->GetSurround().GetSurround() !=
-                        css::text::WrapTextMode_THROUGHT )
+                        css::text::WrapTextMode_THROUGH )
                        bNotify = false;
                 }
                 if( bNotify )
diff --git a/sw/source/core/objectpositioning/anchoredobjectposition.cxx b/sw/source/core/objectpositioning/anchoredobjectposition.cxx
index 3a4d55f0f88d..047e48322134 100644
--- a/sw/source/core/objectpositioning/anchoredobjectposition.cxx
+++ b/sw/source/core/objectpositioning/anchoredobjectposition.cxx
@@ -175,7 +175,7 @@ SwTwips SwAnchoredObjectPosition::GetTopForObjPos( const SwFrame& _rFrame,
                 rTextFrame.GetUpperSpaceAmountConsideredForPrevFrameAndPageGrid();
 
             const SwFormatSurround& rSurround = mpFrameFormat->GetSurround();
-            bool bWrapThrough = rSurround.GetSurround() == css::text::WrapTextMode_THROUGHT;
+            bool bWrapThrough = rSurround.GetSurround() == css::text::WrapTextMode_THROUGH;
             // If the frame format is a TextBox of a draw shape, then use the
             // surround of the original shape.
             SwTextBoxHelper::getShapeWrapThrough(mpFrameFormat, bWrapThrough);
diff --git a/sw/source/core/objectpositioning/tocntntanchoredobjectposition.cxx b/sw/source/core/objectpositioning/tocntntanchoredobjectposition.cxx
index 74967f30b76b..023014503d7b 100644
--- a/sw/source/core/objectpositioning/tocntntanchoredobjectposition.cxx
+++ b/sw/source/core/objectpositioning/tocntntanchoredobjectposition.cxx
@@ -162,7 +162,7 @@ void SwToContentAnchoredObjectPosition::CalcPosition()
     // determine, if object has no surrounding.
     const SwFormatSurround& rSurround = rFrameFormat.GetSurround();
     const bool bNoSurround = rSurround.GetSurround() == css::text::WrapTextMode_NONE;
-    const bool bWrapThrough = rSurround.GetSurround() == css::text::WrapTextMode_THROUGHT;
+    const bool bWrapThrough = rSurround.GetSurround() == css::text::WrapTextMode_THROUGH;
 
     // new class <SwEnvironmentOfAnchoredObject>
     SwEnvironmentOfAnchoredObject aEnvOfObj( DoesObjFollowsTextFlow() );
diff --git a/sw/source/core/objectpositioning/tolayoutanchoredobjectposition.cxx b/sw/source/core/objectpositioning/tolayoutanchoredobjectposition.cxx
index 82f731a55521..0e08bb889593 100644
--- a/sw/source/core/objectpositioning/tolayoutanchoredobjectposition.cxx
+++ b/sw/source/core/objectpositioning/tolayoutanchoredobjectposition.cxx
@@ -74,7 +74,7 @@ void SwToLayoutAnchoredObjectPosition::CalcPosition()
         if ( ( bFlyAtFly &&
                ( eVertOrient == text::VertOrientation::CENTER ||
                  eVertOrient == text::VertOrientation::BOTTOM ) &&
-             css::text::WrapTextMode_THROUGHT != rFrameFormat.GetSurround().GetSurround() &&
+             css::text::WrapTextMode_THROUGH != rFrameFormat.GetSurround().GetSurround() &&
              !GetAnchorFrame().HasFixSize() ) )
         {
             eVertOrient = text::VertOrientation::TOP;
diff --git a/sw/source/core/text/itratr.cxx b/sw/source/core/text/itratr.cxx
index f37b593b8d91..4bcc6987705d 100644
--- a/sw/source/core/text/itratr.cxx
+++ b/sw/source/core/text/itratr.cxx
@@ -501,7 +501,7 @@ static void lcl_MinMaxNode( SwFrameFormat* pNd, SwMinMaxNodeArgs* pIn )
     nMax += rLR.GetLeft();
     nMax += rLR.GetRight();
 
-    if( css::text::WrapTextMode_THROUGHT == pNd->GetSurround().GetSurround() )
+    if( css::text::WrapTextMode_THROUGH == pNd->GetSurround().GetSurround() )
     {
         pIn->Minimum( nMin );
         return;
diff --git a/sw/source/core/text/txtfly.cxx b/sw/source/core/text/txtfly.cxx
index 0582d14e29ff..f28603b071ad 100644
--- a/sw/source/core/text/txtfly.cxx
+++ b/sw/source/core/text/txtfly.cxx
@@ -508,7 +508,7 @@ bool SwTextFly::DrawTextOpaque( SwDrawTextInfo &rInf )
                     const SwFormatAnchor& rAnchor = pFormat->GetAnchor();
                     // Only the ones who are opaque and more to the top
                     if( ! rFly.IsBackgroundTransparent() &&
-                        css::text::WrapTextMode_THROUGHT == rSur.GetSurround() &&
+                        css::text::WrapTextMode_THROUGH == rSur.GetSurround() &&
                         ( !rSur.IsAnchorOnly() ||
                           // #i68520#
                           GetMaster() == rFly.GetAnchorFrame() ||
@@ -599,7 +599,7 @@ void SwTextFly::DrawFlyRect( OutputDevice* pOut, const SwRect &rRect )
                 // #i47804# - consider transparent graphics
                 // and OLE objects.
                 bool bClipFlyArea =
-                        ( ( css::text::WrapTextMode_THROUGHT == rSur.GetSurround() )
+                        ( ( css::text::WrapTextMode_THROUGH == rSur.GetSurround() )
                           // #i68520#
                           ? (pAnchoredObjTmp->GetDrawObj()->GetLayer() != nHellId)
                           : !rSur.IsContour() ) &&
@@ -1026,7 +1026,7 @@ bool SwTextFly::ForEach( const SwRect &rRect, SwRect* pRect, bool bAvoid ) const
                     // formatting. In LineIter::DrawText() it is "just"
                     // necessary to cleverly set the ClippingRegions
                     const SwFormatAnchor& rAnchor = pFormat->GetAnchor();
-                    if( ( css::text::WrapTextMode_THROUGHT == rSur.GetSurround() &&
+                    if( ( css::text::WrapTextMode_THROUGH == rSur.GetSurround() &&
                           ( !rSur.IsAnchorOnly() ||
                             // #i68520#
                             GetMaster() == pAnchoredObj->GetAnchorFrame() ||
@@ -1128,7 +1128,7 @@ void SwTextFly::CalcRightMargin( SwRect &rFly,
         if ( pNext == mpCurrAnchoredObj )
             continue;
         eSurroundForTextWrap = GetSurroundForTextWrap( pNext );
-        if( css::text::WrapTextMode_THROUGHT == eSurroundForTextWrap )
+        if( css::text::WrapTextMode_THROUGH == eSurroundForTextWrap )
             continue;
 
         const SwRect aTmp( SwContourCache::CalcBoundRect
@@ -1220,7 +1220,7 @@ void SwTextFly::CalcLeftMargin( SwRect &rFly,
         if( pNext == mpCurrAnchoredObj )
             continue;
         css::text::WrapTextMode eSurroundForTextWrap = GetSurroundForTextWrap( pNext );
-        if( css::text::WrapTextMode_THROUGHT == eSurroundForTextWrap )
+        if( css::text::WrapTextMode_THROUGH == eSurroundForTextWrap )
             continue;
 
         const SwRect aTmp( SwContourCache::CalcBoundRect
@@ -1323,7 +1323,7 @@ css::text::WrapTextMode SwTextFly::GetSurroundForTextWrap( const SwAnchoredObjec
     }
 
     // in cause of run-through and nowrap ignore smartly
-    if( css::text::WrapTextMode_THROUGHT == eSurroundForTextWrap ||
+    if( css::text::WrapTextMode_THROUGH == eSurroundForTextWrap ||
         css::text::WrapTextMode_NONE == eSurroundForTextWrap )
         return eSurroundForTextWrap;
 
diff --git a/sw/source/core/unocore/unoframe.cxx b/sw/source/core/unocore/unoframe.cxx
index c1222db074da..335987d46300 100644
--- a/sw/source/core/unocore/unoframe.cxx
+++ b/sw/source/core/unocore/unoframe.cxx
@@ -1371,7 +1371,7 @@ SdrObject *SwXFrame::GetOrCreateSdrObject(SwFlyFrameFormat &rFormat)
 
         const ::SwFormatSurround& rSurround = rFormat.GetSurround();
         pObject->SetLayer(
-            ( css::text::WrapTextMode_THROUGHT == rSurround.GetSurround() &&
+            ( css::text::WrapTextMode_THROUGH == rSurround.GetSurround() &&
               !rFormat.GetOpaque().GetValue() ) ? pDoc->getIDocumentDrawModelAccess().GetHellId()
                                              : pDoc->getIDocumentDrawModelAccess().GetHeavenId() );
         pDrawModel->GetPage(0)->InsertObject( pObject );
diff --git a/sw/source/filter/html/htmlcss1.cxx b/sw/source/filter/html/htmlcss1.cxx
index d3fe586b3d95..bc7ae7fc0b27 100644
--- a/sw/source/filter/html/htmlcss1.cxx
+++ b/sw/source/filter/html/htmlcss1.cxx
@@ -1947,7 +1947,7 @@ void SwHTMLParser::SetAnchorAndAdjustment( const SfxItemSet & /*rItemSet*/,
     sal_Int16 eHoriRel = text::RelOrientation::FRAME;
     sal_Int16 eVertRel = text::RelOrientation::FRAME;
     SwTwips nHoriPos = 0, nVertPos = 0;
-    css::text::WrapTextMode eSurround = css::text::WrapTextMode_THROUGHT;
+    css::text::WrapTextMode eSurround = css::text::WrapTextMode_THROUGH;
     if( SVX_CSS1_POS_ABSOLUTE == rPropInfo.m_ePosition )
     {
         if( SVX_CSS1_LTYPE_TWIP == rPropInfo.m_eLeftType &&
diff --git a/sw/source/filter/html/htmldrawreader.cxx b/sw/source/filter/html/htmldrawreader.cxx
index dfbd0172b9e1..3778ba035adb 100644
--- a/sw/source/filter/html/htmldrawreader.cxx
+++ b/sw/source/filter/html/htmldrawreader.cxx
@@ -173,7 +173,7 @@ void SwHTMLParser::InsertDrawObject( SdrObject* pNewDrawObj,
         // #i26791# - direct positioning for <SwDoc::Insert(..)>
         pNewDrawObj->SetRelativePos( Point(rCSS1PropInfo.m_nLeft + nLeftSpace,
                                            rCSS1PropInfo.m_nTop + nUpperSpace) );
-        aFrameSet.Put( SwFormatSurround(css::text::WrapTextMode_THROUGHT) );
+        aFrameSet.Put( SwFormatSurround(css::text::WrapTextMode_THROUGH) );
     }
     else if( SvxAdjust::Left == rCSS1PropInfo.m_eFloat ||
              text::HoriOrientation::LEFT == eHoriOri )
diff --git a/sw/source/filter/html/htmlform.cxx b/sw/source/filter/html/htmlform.cxx
index 63cf7df0479c..639635d05cbc 100644
--- a/sw/source/filter/html/htmlform.cxx
+++ b/sw/source/filter/html/htmlform.cxx
@@ -1091,7 +1091,7 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             nYPos = convertTwipToMm100( rCSS1PropInfo.m_nTop ) + nUpperSpace;
             bSetPos = true;
 
-            nSurround = text::WrapTextMode_THROUGHT;
+            nSurround = text::WrapTextMode_THROUGH;
             bSetSurround = true;
         }
         else if( SvxAdjust::Left == rCSS1PropInfo.m_eFloat ||
diff --git a/sw/source/filter/html/htmlgrin.cxx b/sw/source/filter/html/htmlgrin.cxx
index 33c585ecc95d..019b7e945874 100644
--- a/sw/source/filter/html/htmlgrin.cxx
+++ b/sw/source/filter/html/htmlgrin.cxx
@@ -274,7 +274,7 @@ void SwHTMLParser::RegisterFlyFrame( SwFrameFormat *pFlyFormat )
     // automatically anchored frames must be moved forward by one position
     if( RES_DRAWFRMFMT != pFlyFormat->Which() &&
         (RndStdIds::FLY_AT_PARA == pFlyFormat->GetAnchor().GetAnchorId()) &&
-        css::text::WrapTextMode_THROUGHT == pFlyFormat->GetSurround().GetSurround() )
+        css::text::WrapTextMode_THROUGH == pFlyFormat->GetSurround().GetSurround() )
     {
         m_aMoveFlyFrames.push_back( pFlyFormat );
         m_aMoveFlyCnts.push_back( m_pPam->GetPoint()->nContent.GetIndex() );
diff --git a/sw/source/filter/html/htmlplug.cxx b/sw/source/filter/html/htmlplug.cxx
index 4557579fb097..94d38e6aeb25 100644
--- a/sw/source/filter/html/htmlplug.cxx
+++ b/sw/source/filter/html/htmlplug.cxx
@@ -446,7 +446,7 @@ void SwHTMLParser::InsertEmbed()
         aAnchor.SetAnchor( m_pPam->GetPoint() );
         aFrameSet.Put( aAnchor );
         aFrameSet.Put( SwFormatHoriOrient( 0, text::HoriOrientation::LEFT, text::RelOrientation::FRAME) );
-        aFrameSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGHT ) );
+        aFrameSet.Put( SwFormatSurround( css::text::WrapTextMode_THROUGH ) );
         aFrameSet.Put( SwFormatVertOrient( 0, text::VertOrientation::TOP, text::RelOrientation::PRINT_AREA ) );
     }
 
@@ -1048,7 +1048,7 @@ Writer& OutHTML_FrameFormatOLENode( Writer& rWrt, const SwFrameFormat& rFrameFor
         }
 
         if ((RndStdIds::FLY_AT_PARA == rFrameFormat.GetAnchor().GetAnchorId()) &&
-            css::text::WrapTextMode_THROUGHT == rFrameFormat.GetSurround().GetSurround() )
+            css::text::WrapTextMode_THROUGH == rFrameFormat.GetSurround().GetSurround() )
         {
             // Das Plugin ist HIDDEN
             sOut.append(' ').append(OOO_STRING_SW_HTML_O_Hidden);
diff --git a/sw/source/filter/html/swhtml.cxx b/sw/source/filter/html/swhtml.cxx
index d1b25df5c7cb..8e62ead5c06e 100644
--- a/sw/source/filter/html/swhtml.cxx
+++ b/sw/source/filter/html/swhtml.cxx
@@ -4487,7 +4487,7 @@ bool SwHTMLParser::HasCurrentParaFlys( bool bNoSurroundOnly,
                         bFound = false;
                         break;
                     }
-                    else if( css::text::WrapTextMode_THROUGHT!=eSurround )
+                    else if( css::text::WrapTextMode_THROUGH!=eSurround )
                     {
                         bFound = true;
                         // weitersuchen: Es koennten ja noch welche ohne
diff --git a/sw/source/filter/ww8/docxsdrexport.cxx b/sw/source/filter/ww8/docxsdrexport.cxx
index 78798095dfcb..3e85f643b608 100644
--- a/sw/source/filter/ww8/docxsdrexport.cxx
+++ b/sw/source/filter/ww8/docxsdrexport.cxx
@@ -720,7 +720,7 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
         case css::text::WrapTextMode_NONE:
             m_pImpl->m_pSerializer->singleElementNS(XML_wp, XML_wrapTopAndBottom, FSEND);
             break;
-        case css::text::WrapTextMode_THROUGHT:
+        case css::text::WrapTextMode_THROUGH:
             m_pImpl->m_pSerializer->singleElementNS(XML_wp, XML_wrapNone, FSEND);
             break;
         case css::text::WrapTextMode_PARALLEL:
diff --git a/sw/source/filter/ww8/rtfattributeoutput.cxx b/sw/source/filter/ww8/rtfattributeoutput.cxx
index 5defc6eccb62..6385c73d009c 100644
--- a/sw/source/filter/ww8/rtfattributeoutput.cxx
+++ b/sw/source/filter/ww8/rtfattributeoutput.cxx
@@ -3058,7 +3058,7 @@ void RtfAttributeOutput::FormatSurround(const SwFormatSurround& rSurround)
         case css::text::WrapTextMode_NONE:
             nWr = 1; // top and bottom
             break;
-        case css::text::WrapTextMode_THROUGHT:
+        case css::text::WrapTextMode_THROUGH:
             nWr = 3; // none
             break;
         case css::text::WrapTextMode_PARALLEL:
diff --git a/sw/source/filter/ww8/wrtw8esh.cxx b/sw/source/filter/ww8/wrtw8esh.cxx
index a1d7f8a1f243..0e1ebe84c0e2 100644
--- a/sw/source/filter/ww8/wrtw8esh.cxx
+++ b/sw/source/filter/ww8/wrtw8esh.cxx
@@ -843,14 +843,14 @@ void PlcDrawObj::WritePlc( WW8Export& rWrt ) const
              over the following dummy 0x01 graphic
             */
             if (rFrameFormat.IsInline())
-                eSurround = css::text::WrapTextMode_THROUGHT;
+                eSurround = css::text::WrapTextMode_THROUGH;
 
             switch (eSurround)
             {
                 case css::text::WrapTextMode_NONE:
                     nFlags |= 0x0020;
                     break;
-                case css::text::WrapTextMode_THROUGHT:
+                case css::text::WrapTextMode_THROUGH:
                     nFlags |= 0x0060;
                     break;
                 case css::text::WrapTextMode_PARALLEL:
@@ -2124,7 +2124,7 @@ sal_Int32 SwBasicEscherEx::WriteFlyFrameAttr(const SwFrameFormat& rFormat,
     // SwWW8ImplReader::Read_GrafLayer() imports these as opaque
     // unconditionally, so if both are true, don't export the property.
     bool bIsInHeader = sw::IsFlyFrameFormatInHeader(rFormat);
-    bool bIsThrought = rFormat.GetSurround().GetValue() == css::text::WrapTextMode_THROUGHT;
+    bool bIsThrought = rFormat.GetSurround().GetValue() == css::text::WrapTextMode_THROUGH;
 
     if (bIsInHeader)
     {
diff --git a/sw/source/filter/ww8/ww8graf.cxx b/sw/source/filter/ww8/ww8graf.cxx
index a6b659775660..7d843a225a0a 100644
--- a/sw/source/filter/ww8/ww8graf.cxx
+++ b/sw/source/filter/ww8/ww8graf.cxx
@@ -1347,7 +1347,7 @@ SdrObject* SwWW8ImplReader::ReadGrafPrimitive(short& rLeft, SfxAllItemSet &rSet)
 
     if( rLeft >= SVBT16ToShort(aHd.cb) )    // Vorsichtsmassmahme
     {
-        rSet.Put(SwFormatSurround(css::text::WrapTextMode_THROUGHT));
+        rSet.Put(SwFormatSurround(css::text::WrapTextMode_THROUGH));
         switch (SVBT16ToShort(aHd.dpk) & 0xff )
         {
             case 0:
@@ -2541,7 +2541,7 @@ SwFrameFormat* SwWW8ImplReader::Read_GrafLayer( long nGrafAnchorCp )
             eSurround = css::text::WrapTextMode_NONE;
             break;
         case 3: // 3 wrap as if no object present
-            eSurround = css::text::WrapTextMode_THROUGHT;
+            eSurround = css::text::WrapTextMode_THROUGH;
             break;
         case 4: // 4 wrap tightly around object
         case 5: // 5 wrap tightly, but allow holes
@@ -2612,7 +2612,7 @@ SwFrameFormat* SwWW8ImplReader::Read_GrafLayer( long nGrafAnchorCp )
 
     // #i18732# - Switch on 'follow text flow', if object is laid out
     // inside table cell and its wrapping isn't 'SURROUND_THROUGH'
-    if (bLayoutInTableCell && eSurround != css::text::WrapTextMode_THROUGHT)
+    if (bLayoutInTableCell && eSurround != css::text::WrapTextMode_THROUGH)
     {
         SwFormatFollowTextFlow aFollowTextFlow( true );
         aFlySet.Put( aFollowTextFlow );
diff --git a/sw/source/filter/ww8/ww8par.cxx b/sw/source/filter/ww8/ww8par.cxx
index 93bcea47f060..797518cc2ae5 100644
--- a/sw/source/filter/ww8/ww8par.cxx
+++ b/sw/source/filter/ww8/ww8par.cxx
@@ -2193,7 +2193,7 @@ void SwWW8ImplReader::Read_HdFtTextAsHackedFrame(WW8_CP nStart, WW8_CP nLen,
     if( eFrameSize != aSz.GetWidthSizeType() )
         aSz.SetWidthSizeType( eFrameSize );
     pFrame->SetFormatAttr(aSz);
-    pFrame->SetFormatAttr(SwFormatSurround(css::text::WrapTextMode_THROUGHT));
+    pFrame->SetFormatAttr(SwFormatSurround(css::text::WrapTextMode_THROUGH));
     pFrame->SetFormatAttr(SwFormatHoriOrient(0, text::HoriOrientation::LEFT)); //iFOO
 
     // #i43427# - send frame for header/footer into background.
diff --git a/sw/source/ui/frmdlg/frmpage.cxx b/sw/source/ui/frmdlg/frmpage.cxx
index b220f872144b..d3b1fc122757 100644
--- a/sw/source/ui/frmdlg/frmpage.cxx
+++ b/sw/source/ui/frmdlg/frmpage.cxx
@@ -2311,7 +2311,7 @@ void SwFramePage::Init(const SfxItemSet& rSet, bool bReset)
     const SwFormatSurround& rSurround = static_cast<const SwFormatSurround&>(rSet.Get(RES_SURROUND));
     m_pExampleWN->SetWrap( rSurround.GetSurround() );
 
-    if ( rSurround.GetSurround() == css::text::WrapTextMode_THROUGHT )
+    if ( rSurround.GetSurround() == css::text::WrapTextMode_THROUGH )
     {
         const SvxOpaqueItem& rOpaque = static_cast<const SvxOpaqueItem&>(rSet.Get(RES_OPAQUE));
         m_pExampleWN->SetTransparent(!rOpaque.GetValue());
diff --git a/sw/source/ui/frmdlg/wrap.cxx b/sw/source/ui/frmdlg/wrap.cxx
index 631902ce2699..02c3a58682e5 100644
--- a/sw/source/ui/frmdlg/wrap.cxx
+++ b/sw/source/ui/frmdlg/wrap.cxx
@@ -232,7 +232,7 @@ void SwWrapTabPage::Reset(const SfxItemSet *rSet)
             break;
         }
 
-        case css::text::WrapTextMode_THROUGHT:
+        case css::text::WrapTextMode_THROUGH:
         {
             // transparent ?
             pBtn = m_pWrapThroughRB;
@@ -317,7 +317,7 @@ bool SwWrapTabPage::FillItemSet(SfxItemSet *rSet)
         aSur.SetSurround(css::text::WrapTextMode_PARALLEL);
     else if (m_pWrapThroughRB->IsChecked())
     {
-        aSur.SetSurround(css::text::WrapTextMode_THROUGHT);
+        aSur.SetSurround(css::text::WrapTextMode_THROUGH);
         if (m_pWrapTransparentCB->IsChecked() && !m_bDrawMode)
             aOp.SetValue(false);
     }
@@ -498,7 +498,7 @@ void SwWrapTabPage::ActivatePage(const SfxItemSet& rSet)
     const SwFormatSurround& rSurround = static_cast<const SwFormatSurround&>(rSet.Get(RES_SURROUND));
     css::text::WrapTextMode nSur = rSurround.GetSurround();
 
-    m_pWrapTransparentCB->Enable( bEnable && !m_bHtmlMode && nSur == css::text::WrapTextMode_THROUGHT );
+    m_pWrapTransparentCB->Enable( bEnable && !m_bHtmlMode && nSur == css::text::WrapTextMode_THROUGH );
     if(m_bHtmlMode)
     {
         const SwFormatHoriOrient& rHori = static_cast<const SwFormatHoriOrient&>(rSet.Get(RES_HORI_ORIENT));
diff --git a/sw/source/ui/vba/vbawrapformat.cxx b/sw/source/ui/vba/vbawrapformat.cxx
index c585b7455a5a..e12cebe0c66c 100644
--- a/sw/source/ui/vba/vbawrapformat.cxx
+++ b/sw/source/ui/vba/vbawrapformat.cxx
@@ -56,7 +56,7 @@ void SwVbaWrapFormat::makeWrap()
             case word::WdWrapType::wdWrapNone:
             case word::WdWrapType::wdWrapThrough:
             {
-                eTextMode = text::WrapTextMode_THROUGHT;
+                eTextMode = text::WrapTextMode_THROUGH;
                 break;
             }
             case word::WdWrapType::wdWrapInline:
@@ -98,7 +98,7 @@ void SwVbaWrapFormat::makeWrap()
             nType = word::WdWrapType::wdWrapTopBottom;
             break;
         }
-        case text::WrapTextMode_THROUGHT:
+        case text::WrapTextMode_THROUGH:
         {
             nType = word::WdWrapType::wdWrapNone;
             break;
diff --git a/sw/source/uibase/shells/basesh.cxx b/sw/source/uibase/shells/basesh.cxx
index 101fc812c9dc..f0b6b5775965 100644
--- a/sw/source/uibase/shells/basesh.cxx
+++ b/sw/source/uibase/shells/basesh.cxx
@@ -1095,8 +1095,8 @@ void SwBaseShell::Execute(SfxRequest &rReq)
                 case RndStdIds::FLY_AT_FLY:
                 case RndStdIds::FLY_AT_PAGE:
                     //Wrap through, left or from left, top, from top
-                    if(eSurround != css::text::WrapTextMode_THROUGHT)
-                        aSet.Put(SwFormatSurround(css::text::WrapTextMode_THROUGHT));
+                    if(eSurround != css::text::WrapTextMode_THROUGH)
+                        aSet.Put(SwFormatSurround(css::text::WrapTextMode_THROUGH));
 
                     if( eVOrient != text::VertOrientation::TOP && eVOrient != text::VertOrientation::NONE)
                         aSet.Put(SwFormatVertOrient(0, text::VertOrientation::TOP));
@@ -1119,8 +1119,8 @@ void SwBaseShell::Execute(SfxRequest &rReq)
 
                 case RndStdIds::FLY_AT_CHAR:
                     // left, from left, right, top, wrap through
-                    if(eSurround != css::text::WrapTextMode_THROUGHT)
-                        aSet.Put(SwFormatSurround(css::text::WrapTextMode_THROUGHT));
+                    if(eSurround != css::text::WrapTextMode_THROUGH)
+                        aSet.Put(SwFormatSurround(css::text::WrapTextMode_THROUGH));
 
                     if( eVOrient != text::VertOrientation::TOP)
                         aSet.Put(SwFormatVertOrient(0, text::VertOrientation::TOP));
@@ -1734,21 +1734,21 @@ void SwBaseShell::GetState( SfxItemSet &rSet )
                                  && (nAnchorType != RndStdIds::FLY_AT_CHAR)
                                  && (nAnchorType != RndStdIds::FLY_AT_PAGE)));
                             if(bObj)
-                                bSet = nSurround == css::text::WrapTextMode_THROUGHT && rSh.GetLayerId();
+                                bSet = nSurround == css::text::WrapTextMode_THROUGH && rSh.GetLayerId();
                             else
-                                bSet = nSurround == css::text::WrapTextMode_THROUGHT && bOpaque;
+                                bSet = nSurround == css::text::WrapTextMode_THROUGH && bOpaque;
                         break;
                         case FN_FRAME_WRAPTHRU_TRANSP:
                             bDisable |= bHtmlMode;
                             if(bObj)
-                                bSet = nSurround == css::text::WrapTextMode_THROUGHT && !rSh.GetLayerId();
+                                bSet = nSurround == css::text::WrapTextMode_THROUGH && !rSh.GetLayerId();
                             else
-                                bSet = nSurround == css::text::WrapTextMode_THROUGHT && !bOpaque;
+                                bSet = nSurround == css::text::WrapTextMode_THROUGH && !bOpaque;
                         break;
                         case FN_FRAME_WRAP_CONTOUR:
                             bDisable |= bHtmlMode;
                             //no contour available whenn no wrap or wrap through is set
-                            bDisable |= (nSurround == css::text::WrapTextMode_NONE || nSurround == css::text::WrapTextMode_THROUGHT);
+                            bDisable |= (nSurround == css::text::WrapTextMode_NONE || nSurround == css::text::WrapTextMode_THROUGH);
                             if( !bDisable )
                             {
                                 SelectionType nSel = rSh.GetSelectionType();
@@ -1899,7 +1899,7 @@ void SwBaseShell::SetWrapMode( sal_uInt16 nSlot )
                     aWrap.SetContour(false);
                 SAL_FALLTHROUGH;
             case FN_FRAME_WRAPTHRU:
-                nSurround = css::text::WrapTextMode_THROUGHT;
+                nSurround = css::text::WrapTextMode_THROUGH;
                 break;
 
             case FN_FRAME_WRAP_LEFT:
@@ -1919,7 +1919,7 @@ void SwBaseShell::SetWrapMode( sal_uInt16 nSlot )
         {
             // Defaulting the contour wrap on draw objects.
             if (bObj && nOldSurround != nSurround &&
-                (nOldSurround == css::text::WrapTextMode_NONE || nOldSurround == css::text::WrapTextMode_THROUGHT))
+                (nOldSurround == css::text::WrapTextMode_NONE || nOldSurround == css::text::WrapTextMode_THROUGH))
             {
                 aWrap.SetContour(true);
             }
diff --git a/sw/source/uibase/utlui/attrdesc.cxx b/sw/source/uibase/utlui/attrdesc.cxx
index 271f442eaf65..4e327f4768d5 100644
--- a/sw/source/uibase/utlui/attrdesc.cxx
+++ b/sw/source/uibase/utlui/attrdesc.cxx
@@ -308,8 +308,8 @@ bool SwFormatSurround::GetPresentation
         case css::text::WrapTextMode_NONE:
             nId = STR_SURROUND_NONE;
         break;
-        case css::text::WrapTextMode_THROUGHT:
-            nId = STR_SURROUND_THROUGHT;
+        case css::text::WrapTextMode_THROUGH:
+            nId = STR_SURROUND_THROUGH;
         break;
         case css::text::WrapTextMode_PARALLEL:
             nId = STR_SURROUND_PARALLEL;
diff --git a/sw/source/uibase/utlui/attrdesc.hrc b/sw/source/uibase/utlui/attrdesc.hrc
index dafc3a921926..861f8215adb4 100644
--- a/sw/source/uibase/utlui/attrdesc.hrc
+++ b/sw/source/uibase/utlui/attrdesc.hrc
@@ -37,7 +37,7 @@
 #define STR_HEADER                      (RC_ATTR_BEGIN + 13)
 #define STR_NO_HEADER                   (RC_ATTR_BEGIN + 14)
 #define STR_SURROUND_NONE               (RC_ATTR_BEGIN + 15)
-#define STR_SURROUND_THROUGHT           (RC_ATTR_BEGIN + 16)
+#define STR_SURROUND_THROUGH            (RC_ATTR_BEGIN + 16)
 #define STR_SURROUND_PARALLEL           (RC_ATTR_BEGIN + 17)
 #define STR_SURROUND_LEFT               (RC_ATTR_BEGIN + 19)
 #define STR_SURROUND_RIGHT              (RC_ATTR_BEGIN + 20)
diff --git a/sw/source/uibase/utlui/attrdesc.src b/sw/source/uibase/utlui/attrdesc.src
index 7e7e46409bdf..3bc55fa38e37 100644
--- a/sw/source/uibase/utlui/attrdesc.src
+++ b/sw/source/uibase/utlui/attrdesc.src
@@ -90,7 +90,7 @@ String STR_SURROUND_NONE
 {
     Text [ en-US ] = "No wrap" ;
 };
-String STR_SURROUND_THROUGHT
+String STR_SURROUND_THROUGH
 {
     Text [ en-US ] = "Through" ;
 };
diff --git a/vbahelper/source/vbahelper/vbashapes.cxx b/vbahelper/source/vbahelper/vbashapes.cxx
index 3e2acc39dfae..52da448da4c2 100644
--- a/vbahelper/source/vbahelper/vbashapes.cxx
+++ b/vbahelper/source/vbahelper/vbashapes.cxx
@@ -405,7 +405,7 @@ ScVbaShapes::setDefaultShapeProperties( const uno::Reference< drawing::XShape >&
     uno::Reference< beans::XPropertySet > xPropertySet( xShape, uno::UNO_QUERY_THROW );
     xPropertySet->setPropertyValue( "FillStyle", uno::makeAny( OUString("SOLID") ) );
     xPropertySet->setPropertyValue( "FillColor", uno::makeAny( sal_Int32(0xFFFFFF) )  );
-    xPropertySet->setPropertyValue( "TextWordWrap", uno::makeAny( text::WrapTextMode_THROUGHT )  );
+    xPropertySet->setPropertyValue( "TextWordWrap", uno::makeAny( text::WrapTextMode_THROUGH )  );
     //not find in OOo2.3
     //xPropertySet->setPropertyValue("Opaque", uno::makeAny( sal_True )  );
 }
diff --git a/wizards/com/sun/star/wizards/letter/LetterDocument.py b/wizards/com/sun/star/wizards/letter/LetterDocument.py
index dd0484200113..5860f280418b 100644
--- a/wizards/com/sun/star/wizards/letter/LetterDocument.py
+++ b/wizards/com/sun/star/wizards/letter/LetterDocument.py
@@ -29,7 +29,7 @@ from com.sun.star.text.VertOrientation import NONE as NONEVERT
 from com.sun.star.text.RelOrientation import PAGE_FRAME
 from com.sun.star.text.TextContentAnchorType import AT_PAGE
 from com.sun.star.text.SizeType import FIX
-from com.sun.star.text.WrapTextMode import THROUGHT
+from com.sun.star.text.WrapTextMode import THROUGH
 from com.sun.star.awt.FontWeight import BOLD
 from com.sun.star.beans import UnknownPropertyException
 
@@ -184,7 +184,7 @@ class BusinessPaperObject(object):
             self.xFrame.AnchorType = AT_PAGE
             self.xFrame.SizeType = FIX
 
-            self.xFrame.TextWrap = THROUGHT
+            self.xFrame.TextWrap = THROUGH
             self.xFrame.Opaque = True
             self.xFrame.BackColor = 15790320
 
diff --git a/writerfilter/source/dmapper/GraphicHelpers.cxx b/writerfilter/source/dmapper/GraphicHelpers.cxx
index 6be0cfa27c67..eae2d27ca647 100644
--- a/writerfilter/source/dmapper/GraphicHelpers.cxx
+++ b/writerfilter/source/dmapper/GraphicHelpers.cxx
@@ -214,7 +214,7 @@ text::WrapTextMode WrapHandler::getWrapMode( )
 {
     // The wrap values do not map directly to our wrap mode,
     // e.g. none in .docx actually means through in LO.
-    text::WrapTextMode nMode = text::WrapTextMode_THROUGHT;
+    text::WrapTextMode nMode = text::WrapTextMode_THROUGH;
 
     switch ( m_nType )
     {
@@ -241,7 +241,7 @@ text::WrapTextMode WrapHandler::getWrapMode( )
             break;
         case NS_ooxml::LN_Value_vml_wordprocessingDrawing_ST_WrapType_none:
         default:
-            nMode = text::WrapTextMode_THROUGHT;
+            nMode = text::WrapTextMode_THROUGH;
     }
 
     return nMode;
diff --git a/writerfilter/source/dmapper/GraphicImport.cxx b/writerfilter/source/dmapper/GraphicImport.cxx
index 27bd7174d994..ac1451f5c7a1 100644
--- a/writerfilter/source/dmapper/GraphicImport.cxx
+++ b/writerfilter/source/dmapper/GraphicImport.cxx
@@ -1089,7 +1089,7 @@ void GraphicImport::lcl_sprm(Sprm& rSprm)
             break;
         case NS_ooxml::LN_EG_WrapType_wrapNone: // 90944; - doesn't contain attributes
             //depending on the behindDoc attribute text wraps through behind or in front of the object
-            m_pImpl->nWrap = text::WrapTextMode_THROUGHT;
+            m_pImpl->nWrap = text::WrapTextMode_THROUGH;
         break;
         case NS_ooxml::LN_EG_WrapType_wrapTopAndBottom: // 90948;
             m_pImpl->nWrap = text::WrapTextMode_NONE;
@@ -1265,7 +1265,7 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
                 }
                 xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_SURROUND ),
                     uno::makeAny((sal_Int32)m_pImpl->nWrap));
-                if( m_pImpl->rDomainMapper.IsInTable() && m_pImpl->bLayoutInCell && m_pImpl->nWrap != text::WrapTextMode_THROUGHT )
+                if( m_pImpl->rDomainMapper.IsInTable() && m_pImpl->bLayoutInCell && m_pImpl->nWrap != text::WrapTextMode_THROUGH )
                     xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_FOLLOW_TEXT_FLOW ),
                         uno::makeAny(true));
 
diff --git a/writerfilter/source/dmapper/OLEHandler.cxx b/writerfilter/source/dmapper/OLEHandler.cxx
index c4ffbfb301e6..8cfc4883bfc7 100644
--- a/writerfilter/source/dmapper/OLEHandler.cxx
+++ b/writerfilter/source/dmapper/OLEHandler.cxx
@@ -170,7 +170,7 @@ void OLEHandler::lcl_sprm(Sprm & rSprm)
                     // Through shapes in the header or footer(that spill into the body) should be in the background.
                     // It is just assumed that all shapes will spill into the body.
                     if( m_rDomainMapper.IsInHeaderFooter() )
-                        xShapeProps->setPropertyValue("Opaque", uno::makeAny(m_nWrapMode != text::WrapTextMode_THROUGHT));
+                        xShapeProps->setPropertyValue("Opaque", uno::makeAny(m_nWrapMode != text::WrapTextMode_THROUGH));
                 }
                 catch( const uno::Exception& e )
                 {
diff --git a/writerfilter/source/rtftok/rtfdispatchvalue.cxx b/writerfilter/source/rtftok/rtfdispatchvalue.cxx
index 00a1776af4e7..457af170ff3f 100644
--- a/writerfilter/source/rtftok/rtfdispatchvalue.cxx
+++ b/writerfilter/source/rtftok/rtfdispatchvalue.cxx
@@ -768,7 +768,7 @@ RTFError RTFDocumentImpl::dispatchValue(RTFKeyword nKeyword, int nParam)
             m_aStates.top().aShape.nWrap = text::WrapTextMode_PARALLEL;
             break;
         case 3:
-            m_aStates.top().aShape.nWrap = text::WrapTextMode_THROUGHT;
+            m_aStates.top().aShape.nWrap = text::WrapTextMode_THROUGH;
             m_aStates.top().aCharacterSprms.set(NS_ooxml::LN_EG_WrapType_wrapNone, std::make_shared<RTFValue>());
             break;
         case 4:
@@ -776,7 +776,7 @@ RTFError RTFDocumentImpl::dispatchValue(RTFKeyword nKeyword, int nParam)
             m_aStates.top().aCharacterSprms.set(NS_ooxml::LN_EG_WrapType_wrapTight, std::make_shared<RTFValue>());
             break;
         case 5:
-            m_aStates.top().aShape.nWrap = text::WrapTextMode_THROUGHT;
+            m_aStates.top().aShape.nWrap = text::WrapTextMode_THROUGH;
             break;
         }
     }
diff --git a/xmloff/source/text/txtexppr.cxx b/xmloff/source/text/txtexppr.cxx
index 65fd45d877b5..2e451cd76bc2 100644
--- a/xmloff/source/text/txtexppr.cxx
+++ b/xmloff/source/text/txtexppr.cxx
@@ -988,7 +988,7 @@ void XMLTextExportPropertySetMapper::ContextFilter(
             if( pWrapParagraphOnlyState )
                 pWrapParagraphOnlyState->mnIndex = -1;
             SAL_FALLTHROUGH;
-        case WrapTextMode_THROUGHT:
+        case WrapTextMode_THROUGH:
             // wrap through: disable only contour
             if( pWrapContourState )
                 pWrapContourState->mnIndex = -1;
diff --git a/xmloff/source/text/txtprhdl.cxx b/xmloff/source/text/txtprhdl.cxx
index fc6514d4c3a8..7fd0f65479f2 100644
--- a/xmloff/source/text/txtprhdl.cxx
+++ b/xmloff/source/text/txtprhdl.cxx
@@ -424,7 +424,7 @@ bool XMLParagraphOnlyPropHdl_Impl::exportXML(
 SvXMLEnumMapEntry<WrapTextMode> const pXML_Wrap_Enum[] =
 {
     { XML_NONE,         WrapTextMode_NONE },
-    { XML_RUN_THROUGH,  WrapTextMode_THROUGHT },
+    { XML_RUN_THROUGH,  WrapTextMode_THROUGH },
     { XML_PARALLEL,     WrapTextMode_PARALLEL },
     { XML_DYNAMIC,      WrapTextMode_DYNAMIC },
     { XML_LEFT,         WrapTextMode_LEFT },


More information about the Libreoffice-commits mailing list
diff --git a/sw/qa/extras/ooxmlimport/ooxmlimport.cxx b/sw/qa/extras/ooxmlimport/ooxmlimport.cxx
index 027c00a8b1cf..056eca1e3ebc 100644
--- a/sw/qa/extras/ooxmlimport/ooxmlimport.cxx
+++ b/sw/qa/extras/ooxmlimport/ooxmlimport.cxx
@@ -427,7 +427,7 @@ DECLARE_OOXMLIMPORT_TEST(testN758883, "n758883.docx")
     xPropertySet.set(getShape(1), uno::UNO_QUERY);
     text::WrapTextMode eValue;
     xPropertySet->getPropertyValue("Surround") >>= eValue;
-    CPPUNIT_ASSERT_EQUAL(eValue, text::WrapTextMode_THROUGHT);
+    CPPUNIT_ASSERT_EQUAL(eValue, text::WrapTextMode_THROUGH);
 
     /*
      * 5th problem: anchor type of the second textbox was wrong.
@@ -874,8 +874,8 @@ DECLARE_OOXMLIMPORT_TEST(testOleAnchor, "ole-anchor.docx")
 {
     // This was AS_CHARACTER, even if the VML style explicitly contains "position:absolute".
     CPPUNIT_ASSERT_EQUAL(text::TextContentAnchorType_AT_CHARACTER, getProperty<text::TextContentAnchorType>(getShape(1), "AnchorType"));
-    // This was DYNAMIC, even if the default is THROUGHT and there is no w10:wrap element in the bugdoc.
-    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGHT, getProperty<text::WrapTextMode>(getShape(1), "Surround"));
+    // This was DYNAMIC, even if the default is THROUGH and there is no w10:wrap element in the bugdoc.
+    CPPUNIT_ASSERT_EQUAL(text::WrapTextMode_THROUGH, getProperty<text::WrapTextMode>(getShape(1), "Surround"));
 }
 
 DECLARE_OOXMLIMPORT_TEST(testTdf48658_transparentOLEheader, "tdf48658_transparentOLEheader.docx")
diff --git a/sw/source/filter/ww8/docxattributeoutput.cxx b/sw/source/filter/ww8/docxattributeoutput.cxx
index d63cba52dccf..fe8ec152a934 100644
--- a/sw/source/filter/ww8/docxattributeoutput.cxx
+++ b/sw/source/filter/ww8/docxattributeoutput.cxx
@@ -399,7 +399,7 @@ void DocxAttributeOutput::PopulateFrameProperties(const SwFrameFormat* pFrameFor
     case css::text::WrapTextMode_NONE:
         attrList->add( FSNS( XML_w, XML_wrap), "none");
         break;
-    case css::text::WrapTextMode_THROUGHT:
+    case css::text::WrapTextMode_THROUGH:
         attrList->add( FSNS( XML_w, XML_wrap), "through");
         break;
     case css::text::WrapTextMode_PARALLEL:
@@ -7519,8 +7519,8 @@ void DocxAttributeOutput::FormatSurround( const SwFormatSurround& rSurround )
                 sType = "square";
                 sSide = "right";
                 break;
-            case css::text::WrapTextMode_THROUGHT:
-                /* empty type and side means throught */
+            case css::text::WrapTextMode_THROUGH:
+                /* empty type and side means through */
             default:
                 break;
         }
@@ -7544,7 +7544,7 @@ void DocxAttributeOutput::FormatSurround( const SwFormatSurround& rSurround )
             case css::text::WrapTextMode_NONE:
                 sWrap = OString( "none" );
                 break;
-            case css::text::WrapTextMode_THROUGHT:
+            case css::text::WrapTextMode_THROUGH:
                 sWrap = OString( "through" );
                 break;
             case css::text::WrapTextMode_DYNAMIC: